@@ -6,10 +6,10 @@ echo "# $EXTENSION/build_order.txt" 				 > $EXTENSION/build_order.txt
 echo "# <scriptname> (without .sh)" 				>> $EXTENSION/build_order.txt
 echo "" 											>> $EXTENSION/build_order.txt
 
-if [[ $INIT_SYSTEM == "systemd" ]] && [[ ! -d /etc/extension/startupfiles ]]; then
+if [[ $(command -v systemctl) != "" ]] && [ ! -d /etc/extension/startupfiles ]; then
 	echo "blfssystemd" 								>> $EXTENSION/build_order.txt
 fi
-if [[ $INIT_SYSTEM == "systemv" ]] && [[ ! -d /etc/extension/startupfiles ]]; then
+if [ -d /etc/rc.d ] && [ ! -d /etc/extension/startupfiles ]; then
 	echo "blfsbootscripts" 							>> $EXTENSION/build_order.txt
 fi
 echo "complete _" 									>> $EXTENSION/build_order.txt
